sdv.constraints.Range
=====================

.. currentmodule:: sdv.constraints

.. autoclass:: Range

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Range.__init__
      ~Range.filter_valid
      ~Range.fit
      ~Range.fit_transform
      ~Range.from_dict
      ~Range.is_valid
      ~Range.reverse_transform
      ~Range.to_dict
      ~Range.transform
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Range.constraint_columns
   
   